@@ -1,12 +1,10 @@
 #!/bin/bash
 
-# 204: Lines should be no longer than 120 chars
-# 303: Using command rather than module
+# ANSIBLE0006: Using command rather than module
 #   we have a few use cases where we need to use curl and rsync
-# 503: Tasks that run when changed should likely be handlers
+# ANSIBLE0016: Tasks that run when changed should likely be handlers
 #   this requires refactoring roles, skipping for now
-# 602: Needed in ironic boot config validation
-SKIPLIST="204,303,503,602"
+SKIPLIST="ANSIBLE0006,ANSIBLE0016"
 
 pushd validations
 for playbook in `find . -type f -regex '.*\.y[a]?ml'`; do
