@@ -21,7 +21,7 @@ except ImportError:
 
 from os import path
 
-from ansible.module_utils.basic import *  # noqa
+from ansible.module_utils.basic import AnsibleModule
 
 DOCUMENTATION = '''
 ---
